@@ -96,6 +96,8 @@ var Plan = GObject.registerClass({
     _init(params) {
         super._init(params);
         this.reset();
+        this._attribution = null;
+        this._attributionUrl = null;
     }
 
     get itineraries() {
@@ -106,6 +108,22 @@ var Plan = GObject.registerClass({
         return this._selectedItinerary;
     }
 
+    get attribution() {
+        return this._attribution;
+    }
+
+    set attribution(attribution) {
+        this._attribution = attribution;
+    }
+
+    get attributionUrl() {
+        return this._attributionUrl;
+    }
+
+    set attributionUrl(attributionUrl) {
+        this._attributionUrl = attributionUrl;
+    }
+
     update(itineraries) {
         this._itineraries = itineraries;
         this.bbox = this._createBBox();
@@ -116,6 +134,8 @@ var Plan = GObject.registerClass({
         this._itineraries = [];
         this.bbox = null;
         this._selectedItinerary = null;
+        this._attribution = null;
+        this._attributionUrl = null;
         this.emit('reset');
     }
 
@@ -137,6 +157,22 @@ var Plan = GObject.registerClass({
         this.emit('error', msg);
     }
 
+    noRouteFound() {
+        this.emit('error', _("No route found."));
+    }
+
+    noTimetable() {
+        this.emit('error', _("No timetable data found for this route."));
+    }
+
+    requestFailed() {
+        this.emit('error', _("Route request failed."));
+    }
+
+    noProvider() {
+        this.emit('error', _("No provider found for this route."));
+    }
+
     _createBBox() {
         let bbox = new Champlain.BoundingBox();
         this._itineraries.forEach(function(itinerary) {
@@ -508,6 +544,10 @@ var Leg = class Leg {
         return this._intermediateStops;
     }
 
+    set intermediateStops(intermediateStops) {
+        this._intermediateStops = intermediateStops;
+    }
+
     get headsign() {
         return this._headsign;
     }
@@ -617,6 +657,10 @@ var Leg = class Leg {
                         case HVT.TAXI_SERVICE:
                             /* TODO: should we have a dedicated taxi icon? */
                             return 'route-car-symbolic';
+
+                        case HVT.AIR_SERVICE:
+                            return 'route-transit-airplane-symbolic';
+
                         default:
                             /* use a fallback question mark icon in case of some future,
                              * for now unknown mode appears */
@@ -632,6 +676,10 @@ var Leg = class Leg {
         return this._walkingInstructions;
     }
 
+    set walkingInstructions(walkingInstructions) {
+        this._walkingInstructions = walkingInstructions;
+    }
+
     /* Pretty print timing for a transit leg, set params.isStart: true when
      * printing for the starting leg of an itinerary.
      * For starting walking legs, only the departure time will be printed,
@@ -718,4 +766,4 @@ function sortItinerariesByDepartureAsc(first, second) {
 
 function sortItinerariesByArrivalDesc(first, second) {
     return first.arrival < second.arrival;
-}
\ No newline at end of file
+}
